Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/__init__.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applications/__init__.py	(revision 5670)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/__init__.py	(revision 5676)
@@ -1,3 +1,3 @@
-"""This package contains everything regarding student applications.
+"""This package contains everything regarding university applicants.
 """
 # Make this a package.
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_container.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applications/tests/test_container.py	(revision 5670)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_container.py	(revision 5676)
@@ -21,12 +21,12 @@
 ##
 """
-Tests for application containers.
+Tests for applicants containers.
 """
 import unittest
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.applications import interfaces
-from waeup.sirp.applications.container import ApplicationContainer
+from waeup.sirp.applicants import interfaces
+from waeup.sirp.applicants.container import ApplicantsContainer
 
-class ApplicationContainerTestCase(unittest.TestCase):
+class ApplicantsContainerTestCase(unittest.TestCase):
 
     def test_interfaces(self):
@@ -34,9 +34,9 @@
         self.assertTrue(
             verifyClass(
-                interfaces.IApplicationContainer, ApplicationContainer)
+                interfaces.IApplicantsContainer, ApplicantsContainer)
             )
         self.assertTrue(
             verifyObject(
-                interfaces.IApplicationContainer, ApplicationContainer())
+                interfaces.IApplicantsContainer, ApplicantsContainer())
             )
         return
@@ -46,5 +46,5 @@
     suite.addTests(
         unittest.TestLoader().loadTestsFromTestCase(
-            ApplicationContainerTestCase,
+            ApplicantsContainerTestCase,
             )
         )
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/container.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applications/container.py	(revision 5670)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/container.py	(revision 5676)
@@ -21,13 +21,13 @@
 ##
 """
-Containers for student applications.
+Containers for university applicants.
 """
 import grok
-from waeup.sirp.applications.interfaces import IApplicationContainer
+from waeup.sirp.applicants.interfaces import IApplicantsContainer
 
-class ApplicationContainer(grok.Container):
-    """An application container contains student applications.
+class ApplicantsContainer(grok.Container):
+    """An applicants container contains university applicants.
     """
-    grok.implements(IApplicationContainer)
+    grok.implements(IApplicantsContainer)
 
     id = None
@@ -39,31 +39,31 @@
 
     def archive(self, app_ids=None):
         """Create on-dist archive of applications stored in this term.
 
         If app_ids is `None`, all applications are archived.
 
         If app_ids contains a single id string, only the respective
-        applications are archived.
+        applicants are archived.
 
         If app_ids contains a list of id strings all of the respective
         application types are saved to disk.
         """
         raise NotImplemented()
 
     def clear(self, app_ids=None, archive=True):
         """Remove applications of type given by 'id'.
 
-        Optionally archive the applications.
+        Optionally archive the applicants.
         
         If id is `None`, all applications are archived.
 
         If id contains a single id string, only the respective
-        applications are archived.
+        applicants are archived.
 
         If id contains a list of id strings all of the respective
-        application types are saved to disk.
+        applicant types are saved to disk.
 
         If `archive` is ``False`` none of the archive-handling is done
-        and respective applications are simply removed from the
+        and respective applicants are simply removed from the
         database.
         """
@@ -39,31 +39,31 @@
 
     def archive(self, app_ids=None):
-        """Create on-dist archive of applications stored in this term.
+        """Create on-dist archive of applicants stored in this term.
 
@@ -39,31 +39,31 @@
 
-        If app_ids is `None`, all applications are archived.
+        If app_ids is `None`, all applicants are archived.
 
         If app_ids contains a single id string, only the respective
@@ -39,31 +39,31 @@
 
         If app_ids contains a list of id strings all of the respective
-        application types are saved to disk.
+        applicants types are saved to disk.
         """
         raise NotImplemented()
@@ -39,31 +39,31 @@
 
     def clear(self, app_ids=None, archive=True):
-        """Remove applications of type given by 'id'.
+        """Remove applicants of type given by 'id'.
 
@@ -39,31 +39,31 @@
         
-        If id is `None`, all applications are archived.
+        If id is `None`, all applicants are archived.
 
         If id contains a single id string, only the respective
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/interfaces.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applications/interfaces.py	(revision 5670)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/interfaces.py	(revision 5676)
@@ -20,30 +20,30 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Interfaces regarding student applications and related components.
 """
 from zope import schema
 from waeup.sirp.interfaces import IWAeUPObject
 
-class IApplicationsRoot(IWAeUPObject):
-    """A container for student application containers.
+class IApplicantsRoot(IWAeUPObject):
+    """A container for university applicants containers.
     """
-    def addApplicationContainer(container, name=None):
-        """Add an application container.
+    def addApplicantsContainer(container, name=None):
+        """Add an applicants container.
 
         Adds an application container that implements `interface`
         under the name `name`.
 
         `container` the container instance to be added. Should
-          implement :class:`IApplicationContainer`.
+          implement :class:`IApplicantsContainer`.
 
         `name`
           the name under which the container will be accessible. We
           usually use names like ``pume_2011`` to indicate, that the
           new container will contain student applications for a
           certain screening type (``pume``) and of the year 2011.
         """
 
-class IApplicationContainer(IWAeUPObject):
-    """An application container contains student applications.
+class IApplicantsContainer(IWAeUPObject):
+    """An applicants container contains university applicants.
 
     """
@@ -54,5 +54,5 @@
 
     title = schema.TextLine(
-        title = u'Short description of the type of applications stored here.',
+        title = u'Short description of the type of applicants stored here.',
         required = True,
         default = u'Untitled',
@@ -84,30 +84,30 @@
 
     def archive(id=None):
         """Create on-dist archive of applications stored in this term.
 
         If id is `None`, all applications are archived.
 
         If id contains a single id string, only the respective
-        applications are archived.
+        applicants are archived.
 
         If id contains a list of id strings all of the respective
         application types are saved to disk.
         """
 
     def clear(id=None, archive=True):
         """Remove applications of type given by 'id'.
 
-        Optionally archive the applications.
+        Optionally archive the applicants.
         
         If id is `None`, all applications are archived.
 
         If id contains a single id string, only the respective
-        applications are archived.
+        applicants are archived.
 
         If id contains a list of id strings all of the respective
-        application types are saved to disk.
+        applicant types are saved to disk.
 
         If `archive` is ``False`` none of the archive-handling is done
-        and respective applications are simply removed from the
+        and respective applicants are simply removed from the
         database.
         """
@@ -20,30 +20,30 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Interfaces regarding student applications and related components.
+"""Interfaces regarding student applicants and related components.
 """
 from zope import schema
@@ -20,30 +20,30 @@
 
-        Adds an application container that implements `interface`
+        Adds an applicants container that implements `interface`
         under the name `name`.
 
@@ -20,30 +20,30 @@
           the name under which the container will be accessible. We
           usually use names like ``pume_2011`` to indicate, that the
-          new container will contain student applications for a
+          new container will contain university applicants for a
           certain screening type (``pume``) and of the year 2011.
         """
@@ -84,30 +84,30 @@
 
     def archive(id=None):
-        """Create on-dist archive of applications stored in this term.
+        """Create on-dist archive of applicants stored in this term.
 
@@ -84,30 +84,30 @@
 
-        If id is `None`, all applications are archived.
+        If id is `None`, all applicants are archived.
 
         If id contains a single id string, only the respective
@@ -84,30 +84,30 @@
 
         If id contains a list of id strings all of the respective
-        application types are saved to disk.
+        applicants types are saved to disk.
         """
 
@@ -84,30 +84,30 @@
 
     def clear(id=None, archive=True):
-        """Remove applications of type given by 'id'.
+        """Remove applicants of type given by 'id'.
 
@@ -84,30 +84,30 @@
         
-        If id is `None`, all applications are archived.
+        If id is `None`, all applicants are archived.
 
         If id contains a single id string, only the respective
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/root.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applications/root.py	(revision 5670)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/root.py	(revision 5676)
@@ -21,29 +21,30 @@
 ##
 """
-The root for applications.
+The root for applicants.
 """
 import grok
 from waeup.sirp.interfaces import IWAeUPSIRPPluggable
-from waeup.sirp.applications.interfaces import IApplicationsRoot
+from waeup.sirp.applicants.interfaces import IApplicantsRoot
 
-class ApplicationsRoot(grok.Container):
-    """The root of student applications-related components.
+class ApplicantsRoot(grok.Container):
+    """The root of applicants-related components. It contains primarily 
+    containers for applicants.
     """
-    grok.implements(IApplicationsRoot)
+    grok.implements(IApplicantsRoot)
 
-    def addApplicationContainer(self, container, name=None):
-        """Add an application container.
+    def addApplicantsContainer(self, container, name=None):
+        """Add an applicants container.
 
         Adds an application container that implements `interface`
         under the name `name`.
 
         `container`
           the container instance to be added. Should
-          implement :class:`IApplicationContainer`.
+          implement :class:`IApplicantsContainer`.
 
         `name`
           the name under which the container will be accessible. We
           usually use names like ``pume_2011`` to indicate, that the
           new container will contain student applications for a
           certain screening type (``pume``) and of the year 2011.
 
@@ -52,6 +53,6 @@
         return
 
-class ApplicationsPlugin(grok.GlobalUtility):
-    """A WAeUPSIRPPlugin that creates an applications root in portal.
+class ApplicantsPlugin(grok.GlobalUtility):
+    """A WAeUPSIRPPlugin that creates an applicants root in portal.
 
     This plugin should be called by a typical
@@ -62,28 +63,28 @@
     Implements :class:`waeup.sirp.interfaces.IWAeUPSIRPPluggable`
     """
-    grok.name('applications')
+    grok.name('applicants')
     grok.implements(IWAeUPSIRPPluggable)
-    log_prefix = 'ApplicationsPlugin'
+    log_prefix = 'ApplicantsPlugin'
 
     def setup(self, site, name, logger):
         """Create a new :class:`ApplicationsRoot` instance in `site`.
         """
-        site['applications'] = ApplicationsRoot()
+        site['applicants'] = ApplicantsRoot()
         logger.info(
-            '%s: Installed applications root.' % (self.log_prefix,)
+            '%s: Installed applicants root.' % (self.log_prefix,)
             )
         return
 
     def update(self, site, name, logger):
         """Update site wide ``applications`` root.
 
         If the site already contains a suitable ``applications`` root,
         leave it that way. If not create one and delete the old one if
         appropriate.
         """
-        app_folder = site.get('applications', None)
+        app_folder = site.get('applicants', None)
         site_name = getattr(site, '__name__', 'Unnamed Site?')
-        if IApplicationsRoot.providedBy(app_folder):
-            # Applications up to date. Return.
+        if IApplicantsRoot.providedBy(app_folder):
+            # Applicants up to date. Return.
             logger.info(
                 '%s: Updating site at %s: Nothing to do.' % (
@@ -92,14 +93,14 @@
             return
         elif app_folder is not None:
             # Applications need update. Remove old instance.
             logger.warn(
-                '%s: Outdated applications folder detected at site %s.'
+                '%s: Outdated applicants folder detected at site %s.'
                 'Removing it.' % (self.log_prefix, site_name)
                     )
-            del site['applications']
-        # Add new applications.
+            del site['applicants']
+        # Add new applicants.
         logger.info(
             '%s: Updating site at %s. Installing '
-            'applications.' % (self.log_prefix, site_name,)
+            'applicants.' % (self.log_prefix, site_name,)
             )
         self.setup(site, name, logger)
@@ -21,29 +21,30 @@
 
-        Adds an application container that implements `interface`
+        Adds an applicants container that implements `interface`
         under the name `name`.
 
@@ -21,29 +21,30 @@
           the name under which the container will be accessible. We
           usually use names like ``pume_2011`` to indicate, that the
-          new container will contain student applications for a
+          new container will contain student applicants for a
           certain screening type (``pume``) and of the year 2011.
 
@@ -62,28 +63,28 @@
 
     def setup(self, site, name, logger):
-        """Create a new :class:`ApplicationsRoot` instance in `site`.
+        """Create a new :class:`ApplicantsRoot` instance in `site`.
         """
@@ -62,28 +63,28 @@
 
     def update(self, site, name, logger):
-        """Update site wide ``applications`` root.
+        """Update site wide ``applicants`` root.
 
@@ -62,28 +63,28 @@
 
-        If the site already contains a suitable ``applications`` root,
+        If the site already contains a suitable ``applicants`` root,
         leave it that way. If not create one and delete the old one if
         appropriate.
@@ -92,14 +93,14 @@
             return
         elif app_folder is not None:
-            # Applications need update. Remove old instance.
+            # Applicants need update. Remove old instance.
             logger.warn(
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_root.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applications/tests/test_root.py	(revision 5670)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_root.py	(revision 5676)
@@ -21,5 +21,5 @@
 ##
 """
-Test applications root.
+Test applicants root.
 """
 import logging
@@ -27,7 +27,7 @@
 from StringIO import StringIO
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.applications import interfaces
-from waeup.sirp.applications.root import (
-    ApplicationsRoot, ApplicationsPlugin,
+from waeup.sirp.applicants import interfaces
+from waeup.sirp.applicants.root import (
+    ApplicantsRoot, ApplicantsPlugin,
     )
 
@@ -35,5 +35,5 @@
     pass
 
-class ApplicationsRootTestCase(unittest.TestCase):
+class ApplicantsRootTestCase(unittest.TestCase):
 
     def test_interfaces(self):
@@ -41,16 +41,16 @@
         self.assertTrue(
             verifyClass(
-                interfaces.IApplicationsRoot, ApplicationsRoot)
+                interfaces.IApplicantsRoot, ApplicantsRoot)
             )
         self.assertTrue(
             verifyObject(
-                interfaces.IApplicationsRoot, ApplicationsRoot())
+                interfaces.IApplicantsRoot, ApplicantsRoot())
             )
         return
 
-class ApplicationsRootPluginTestCase(unittest.TestCase):
+class ApplicantsRootPluginTestCase(unittest.TestCase):
     def create_logger(self):
         # create a logger suitable for local tests.
-        test_logger = logging.getLogger('waeup.sirp.applications.testlogger')
+        test_logger = logging.getLogger('waeup.sirp.applicants.testlogger')
         log = StringIO()
         handler = logging.StreamHandler(log)
@@ -83,47 +83,47 @@
     # Real tests start here...
     def test_pluginsetup(self):
         # Make sure we can add ApplicationsRoot to sites.
         site = FakeSite()
-        plugin = ApplicationsPlugin()
+        plugin = ApplicantsPlugin()
         plugin.setup(site, 'blah', self.logger)
-        self.assertTrue('applications' in site.keys())
+        self.assertTrue('applicants' in site.keys())
         log = self.get_log()
-        self.assertTrue('Installed applications root.' in log)
+        self.assertTrue('Installed applicants root.' in log)
         return
 
     def test_update_new(self):
         # Run update on a site without applications root.
         site = FakeSite()
-        plugin = ApplicationsPlugin()
+        plugin = ApplicantsPlugin()
         plugin.update(site, 'blah', self.logger)
-        self.assertTrue('applications' in site.keys())
+        self.assertTrue('applicants' in site.keys())
         log = self.get_log()
         self.assertTrue('Updating site at Unnamed Site' in log)
-        self.assertTrue('Installed applications root.' in log)
+        self.assertTrue('Installed applicants root.' in log)
         return
 
     def test_update_outdated(self):
         # Run update on a site with outdated applications root.
         site = FakeSite()
-        root = object() # # This is not a proper applications root
-        site['applications'] = root
-        plugin = ApplicationsPlugin()
+        root = object() # # This is not a proper applicants root
+        site['applicants'] = root
+        plugin = ApplicantsPlugin()
         plugin.update(site, 'blah', self.logger)
-        self.assertTrue(site['applications'] is not root)
-        self.assertTrue(isinstance(site['applications'], ApplicationsRoot))
+        self.assertTrue(site['applicants'] is not root)
+        self.assertTrue(isinstance(site['applicants'], ApplicantsRoot))
         log = self.get_log()
-        self.assertTrue('Outdated applications folder detected' in log)
+        self.assertTrue('Outdated applicants folder detected' in log)
         self.assertTrue('Updating site at Unnamed Site' in log)
-        self.assertTrue('Installed applications root.' in log)
+        self.assertTrue('Installed applicants root.' in log)
         return
 
     def test_update_uptodate(self):
         # Run update on a site with proper applications root.
         site = FakeSite()
-        root = ApplicationsRoot()
-        site['applications'] = root
-        plugin = ApplicationsPlugin()
+        root = ApplicantsRoot()
+        site['applicants'] = root
+        plugin = ApplicantsPlugin()
         plugin.update(site, 'blah', self.logger)
-        self.assertTrue(site['applications'] is root)
+        self.assertTrue(site['applicants'] is root)
         log = self.get_log()
         self.assertTrue('Updating site at Unnamed Site' in log)
@@ -135,5 +135,5 @@
         site = FakeSite()
         site.__name__ = 'my_site'
-        plugin = ApplicationsPlugin()
+        plugin = ApplicantsPlugin()
         plugin.update(site, 'blah', self.logger)
         log = self.get_log()
@@ -144,6 +144,6 @@
     suite = unittest.TestSuite()
     for testcase in [
-            ApplicationsRootTestCase,
-            ApplicationsRootPluginTestCase,
+            ApplicantsRootTestCase,
+            ApplicantsRootPluginTestCase,
             ]:
         suite.addTests(unittest.TestLoader().loadTestsFromTestCase(testcase))
@@ -83,47 +83,47 @@
     # Real tests start here...
     def test_pluginsetup(self):
-        # Make sure we can add ApplicationsRoot to sites.
+        # Make sure we can add ApplicantsRoot to sites.
         site = FakeSite()
@@ -83,47 +83,47 @@
 
     def test_update_new(self):
-        # Run update on a site without applications root.
+        # Run update on a site without applicants root.
         site = FakeSite()
@@ -83,47 +83,47 @@
 
     def test_update_outdated(self):
-        # Run update on a site with outdated applications root.
+        # Run update on a site with outdated applicants root.
         site = FakeSite()
@@ -83,47 +83,47 @@
 
     def test_update_uptodate(self):
-        # Run update on a site with proper applications root.
+        # Run update on a site with proper applicants root.
         site = FakeSite()
